pub(crate) struct SyncPhysicalRectAu(PhysicalRect<AtomicI32>);Expand description
A PhysicalRect<Au> with shared mutablitiy
It is based on AtomicI32 but is not atomic itself: there is no protection against tearing:
If multiple threads are calling set(), the rectangle may end up with some fields from one call
and some fields from another call.
Compared to AtomicRefCell<PhysicalRect<Au>>:
- Both are meant for uses where despite shared ownership, no concurrency is expected in practice.
- If concurrent access does unexpectedly happen
AtomicRefCellwill panic, whereasSyncPhysicalRectAucan tear and result in invalid/inconsistent data. SyncPhysicalRectAuhas no space overhead,AtomicRefCellstores anAtomicUsizeborrow flagSyncPhysicalRectAuuses relaxed atomic access for each field separately
Tuple Fields
0: PhysicalRect<AtomicI32>Implementations
Sourceimpl SyncPhysicalRectAu
impl SyncPhysicalRectAu
pub(crate) fn new(rect: PhysicalRect<Au>) -> Self
pub(crate) fn get(&self) -> PhysicalRect<Au>
pub(crate) fn set(&self, new_rect: PhysicalRect<Au>)
pub(crate) fn origin(&self) -> PhysicalPoint<Au>
pub(crate) fn size(&self) -> PhysicalSize<Au>
pub(crate) fn set_origin(&self, new_origin: PhysicalPoint<Au>)
pub(crate) fn set_size(&self, new_size: PhysicalSize<Au>)
pub(crate) fn translate(&self, offset: PhysicalSize<Au>)